SystemOrganization addCategory: #ConfigurationOfSwaLint!

Object subclass: #ConfigurationOfSwaLint
	instanceVariableNames: 'project storedDeprecationSetting'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSwaLint'!

!ConfigurationOfSwaLint classSide methodsFor: 'private' stamp: 'topa 4/23/2010 14:48'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSwaLint classSide methodsFor: 'private' stamp: 'topa 4/23/2010 14:48'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSwaLint classSide methodsFor: 'metacello tool support' stamp: 'topa 4/23/2010 14:48'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSwaLint classSide methodsFor: 'metacello tool support' stamp: 'topa 4/23/2010 14:48'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSwaLint classSide methodsFor: 'loading' stamp: 'topa 4/23/2010 14:48'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfSwaLint classSide methodsFor: 'metacello tool support' stamp: 'topa 4/23/2010 14:48'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSwaLint classSide methodsFor: 'accessing' stamp: 'topa 4/23/2010 14:48'!
project

	^self new project! !

!ConfigurationOfSwaLint classSide methodsFor: 'unloading Metacello' stamp: 'topa 4/23/2010 14:48'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSwaLint methodsFor: 'baselines' stamp: 'topa 4/23/2010 16:55'!
baseline200: spec 
	<version: '2.0.0-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://www.squeaksource.com/SwaLint';
			description: 'Initial Baseline for SwaLint 2';
			postLoadDoIt: #postLoadFor200.
		"Requirements"	
		spec
			package: 'AST-Core' with: [spec
				repository: 'http://www.squeaksource.com/rb'];
			package: 'Refactoring-Core' with: [spec 
				requires: 'AST-Core';
				repository: 'http://www.squeaksource.com/rb'].
		spec 
			package: 'SwaLint-Core' with: [spec requires: #('AST-Core' 'Refactoring-Core')]; 
			package: 'SwaLint-PlugIns' with: [ spec requires: 'SwaLint-Core' ];
			package: 'SwaLint-Tests' with: [ spec requires: #('SwaLint-Core' 'SwaLint-PlugIns') ].
		spec
			group: 'default' with: #('PlugIns');
			group: 'Core' with: #('SwaLint-Core');
			group: 'PlugIns' with: #('SwaLint-PlugIns');
			group: 'Tests' with: #('SwaLint-Tests')].
	spec for: #pharo do: [
		spec 
			preLoadDoIt: #preLoadPharo200;
			postLoadDoIt: #postLoadPharo200].! !

!ConfigurationOfSwaLint methodsFor: 'doits' stamp: 'topa 4/23/2010 16:37'!
postLoadFor200

	(((Smalltalk respondsTo: #globals) 
		ifTrue: [Smalltalk globals] "Squeak >=4.1"
		ifFalse: [Smalltalk]) "Pharo and squeak <=4.0"
		at: #SwaLint) perform: #hardReset.! !

!ConfigurationOfSwaLint methodsFor: 'doits' stamp: 'topa 4/23/2010 16:50'!
postLoadPharo200

	self postLoadFor200.
	Preferences setPreference: #raiseDeprecatedWarnings toValue: self storedDeprecationSetting.
	
! !

!ConfigurationOfSwaLint methodsFor: 'doits' stamp: 'topa 4/23/2010 17:04'!
preLoadPharo200

	self storedDeprecationSetting: (Preferences valueOfPreference: #raiseDeprecatedWarnings).
	Preferences setPreference: #raiseDeprecatedWarnings toValue: false.
	! !

!ConfigurationOfSwaLint methodsFor: 'accessing' stamp: 'topa 4/23/2010 14:48'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSwaLint methodsFor: 'accessing' stamp: 'topa 4/23/2010 16:50'!
storedDeprecationSetting
	
	^ storedDeprecationSetting! !

!ConfigurationOfSwaLint methodsFor: 'accessing' stamp: 'topa 4/23/2010 16:50'!
storedDeprecationSetting: anObject
	
	storedDeprecationSetting := anObject! !

!ConfigurationOfSwaLint methodsFor: 'versions' stamp: 'topa 4/23/2010 16:33'!
version200: spec 
	<version: '2.0.0' imports: #('2.0.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'AST-Core' with: 'AST-Core-lr.67';
			package: 'Refactoring-Core' with: 'Refactoring-Core-lr.115';
			package: 'SwaLint-Core' with: 'SwaLint-Core-topa.4';
			package: 'SwaLint-Plugins' with: 'SwaLint-PlugIns-topa.2';
			package: 'SwaLint-Tests' with: 'SwaLint-Tests-topa.2'].! !
